@@ -347,7 +347,7 @@ def parse_args(action, default_chromecast=None) -> argparse.Namespace:
     parser.add_argument("--limit", "-L", "-l", "-queue", "--queue", help=argparse.SUPPRESS)
     parser.add_argument("--skip", "--offset", help=argparse.SUPPRESS)
     parser.add_argument(
-        "--partial", "-P", "--recent", "-R", default=False, const="n", nargs="?", help=argparse.SUPPRESS
+        "--partial", "-P", "--previous", "--recent", default=False, const="n", nargs="?", help=argparse.SUPPRESS
     )
 
     parser.add_argument("--start", "-vs", help=argparse.SUPPRESS)
@@ -384,7 +384,10 @@ def parse_args(action, default_chromecast=None) -> argparse.Namespace:
     args = parser.parse_intermixed_args()
     args.action = action
     args.defaults = []
+
     args.include += args.search
+    if args.include == ["."]:
+        args.include = [str(Path().cwd().resolve())]
 
     if args.db:
         args.database = args.db
