@@ -69,7 +69,7 @@ def construct_query(args) -> Tuple[str, dict]:
         *
     FROM {args.table}
     WHERE 1=1
-        and time_deleted=0
+        and COALESCE(time_deleted,0) = 0
         {args.sql_filter}
         and (category is null or category != '{consts.BLOCK_THE_CHANNEL}')
     ORDER BY 1=1
@@ -104,7 +104,7 @@ def printer(args, query, bindings) -> None:
         tbl = utils.col_resize(tbl, "title", 20)
         tbl = utils.col_resize(tbl, "uploader_url")
 
-        tbl = utils.list_dict_filter_bool(tbl, keep_0=False)
+        tbl = utils.list_dict_filter_bool(tbl)
 
         print(tabulate(tbl, tablefmt="fancy_grid", headers="keys", showindex=False))
 
@@ -234,28 +234,29 @@ def dlstatus() -> None:
     if args.delete:
         return delete_playlists(args, args.delete)
 
-    args.db.register_function(tube_backend.is_supported, deterministic=True)
-
     query, bindings = dl_extract.construct_query(args)
 
     count_paths = ""
     if "time_modified" in query:
         if args.safe:
-            count_paths = ", count(*) FILTER(WHERE time_modified=0 and is_supported(path)) never_downloaded"
+            args.db.register_function(tube_backend.is_supported, deterministic=True)
+            count_paths = (
+                ", count(*) FILTER(WHERE COALESCE(time_modified,0) = 0 and is_supported(path)) never_downloaded"
+            )
         else:
-            count_paths = ", count(*) FILTER(WHERE time_modified=0) never_downloaded"
+            count_paths = ", count(*) FILTER(WHERE COALESCE(time_modified,0) = 0) never_downloaded"
 
     query = f"""select
         coalesce(category, "Playlist-less media") category
         {', ie_key' if 'm.ie_key' in query else ''}
         {', sum(duration) duration' if 'duration' in query else ''}
         {count_paths}
-        {', count(*) FILTER(WHERE time_modified>0 AND error IS NOT NULL) errors' if 'error' in query else ''}
+        {', count(*) FILTER(WHERE COALESCE(time_modified,0) > 0 AND error IS NOT NULL) errors' if 'error' in query else ''}
         {', group_concat(distinct error) error_descriptions' if 'error' in query and args.verbose >= 1 else ''}
     from ({query}) m
     where 1=1
-        and time_downloaded=0
-        and time_deleted=0
+        and COALESCE(time_downloaded,0) = 0
+        and COALESCE(time_deleted,0) = 0
     group by category{', ie_key' if 'm.ie_key' in query else ''}
     order by category nulls last"""
 
