@@ -142,8 +142,10 @@ def tube_opts(args, func_opts=None, playlist_opts: Optional[str] = None) -> dict
 
 
 def is_supported(url) -> bool:  # thank you @dbr
-    ies = yt_dlp.extractor.gen_extractors()
-    for ie in ies:
+    if consts.REGEX_V_REDD_IT.match(url):
+        return True
+
+    for ie in consts.YT_IES:
         if ie.suitable(url) and ie.IE_NAME != "generic":
             return True  # Site has dedicated extractor
     return False
@@ -196,8 +198,8 @@ def consolidate(v: dict) -> Optional[dict]:
     duration = v.pop("duration", None)
     cv["duration"] = 0 if not duration else int(duration)
     cv["time_uploaded"] = upload_date
-    cv["time_created"] = int(datetime.now().timestamp())
-    cv["time_modified"] = 0
+    cv["time_created"] = consts.APPLICATION_START
+    cv["time_modified"] = 0  # this should be 0 if the file has never been downloaded
     cv["time_deleted"] = 0
     cv["time_downloaded"] = 0
     cv["play_count"] = 0
@@ -429,8 +431,8 @@ def save_tube_entry(args, m, info: Optional[dict] = None, error=None, URE=False)
         entry = {
             "path": webpath,
             "time_downloaded": 0,
-            "time_modified": consts.NOW,
-            "time_deleted": consts.NOW if URE else 0,
+            "time_modified": consts.now(),
+            "time_deleted": consts.APPLICATION_START if URE else 0,
             "error": error,
         }
         args.db["media"].upsert(utils.dict_filter_bool(entry), pk="path", alter=True)  # type: ignore
@@ -452,16 +454,16 @@ def save_tube_entry(args, m, info: Optional[dict] = None, error=None, URE=False)
         fs_tags = {}
 
     tube_entry = consolidate(info) or {}
-    tube_entry.pop("play_count", None)
+    tube_entry.pop("play_count", None)  # remove default 0s to not overwrite existing value during upsert
     tube_entry.pop("time_played", None)
 
     entry = {
         **tube_entry,
         **fs_tags,
         "webpath": webpath,
-        "time_modified": consts.NOW,
-        "time_downloaded": 0 if error else consts.NOW,
-        "time_deleted": consts.NOW if URE else 0,
+        "time_modified": consts.now(),
+        "time_downloaded": 0 if error else consts.APPLICATION_START,
+        "time_deleted": consts.APPLICATION_START if URE else 0,
         "error": error,
     }
     args.db["media"].upsert(utils.dict_filter_bool(entry), pk="path", alter=True)  # type: ignore
@@ -574,24 +576,24 @@ def yt(args, m) -> None:
             else:
                 info["local_path"] = ydl.prepare_filename(info)
 
-        ydl_errors = ydl_log["error"] + ydl_log["warning"]
-        ydl_errors = "\n".join([l for l in ydl_errors if not yt_meaningless_errors.match(l)])
-        ydl_full_log = ydl_log["error"] + ydl_log["warning"] + ydl_log["info"]
+    ydl_errors = ydl_log["error"] + ydl_log["warning"]
+    ydl_errors = "\n".join([l for l in ydl_errors if not yt_meaningless_errors.match(l)])
+    ydl_full_log = ydl_log["error"] + ydl_log["warning"] + ydl_log["info"]
 
-        if not ydl_log["error"] and info:
-            log.debug("[%s]: No news is good news", m["path"])
-            save_tube_entry(args, m, info)
-        elif any([yt_recoverable_errors.match(l) for l in ydl_full_log]):
-            log.info("[%s]: Recoverable error matched (will try again later). %s", m["path"], ydl_errors)
-            save_tube_entry(args, m, info, error=ydl_errors)
-        elif any([yt_unrecoverable_errors.match(l) for l in ydl_full_log]):
-            matched_error = [m.string for m in utils.conform([yt_unrecoverable_errors.match(l) for l in ydl_full_log])]
-            log.debug("[%s]: Unrecoverable error matched. %s", m["path"], ydl_errors or utils.combine(matched_error))
-            save_tube_entry(args, m, info, error=ydl_errors, URE=True)
-        elif any([prefix_unrecoverable_errors.match(l) for l in ydl_full_log]):
-            log.warning("[%s]: Prefix error. %s", m["path"], ydl_errors)
-            raise SystemExit(28)
-        else:
-            if ydl_errors != "":
-                log.error("[%s]: Unknown error. %s", m["path"], ydl_errors)
-            save_tube_entry(args, m, info, error=ydl_errors)
+    if not ydl_log["error"] and info:
+        log.debug("[%s]: No news is good news", m["path"])
+        save_tube_entry(args, m, info)
+    elif any([yt_recoverable_errors.match(l) for l in ydl_full_log]):
+        log.info("[%s]: Recoverable error matched (will try again later). %s", m["path"], ydl_errors)
+        save_tube_entry(args, m, info, error=ydl_errors)
+    elif any([yt_unrecoverable_errors.match(l) for l in ydl_full_log]):
+        matched_error = [m.string for m in utils.conform([yt_unrecoverable_errors.match(l) for l in ydl_full_log])]
+        log.debug("[%s]: Unrecoverable error matched. %s", m["path"], ydl_errors or utils.combine(matched_error))
+        save_tube_entry(args, m, info, error=ydl_errors, URE=True)
+    elif any([prefix_unrecoverable_errors.match(l) for l in ydl_full_log]):
+        log.warning("[%s]: Prefix error. %s", m["path"], ydl_errors)
+        raise SystemExit(28)
+    else:
+        if ydl_errors != "":
+            log.error("[%s]: Unknown error. %s", m["path"], ydl_errors)
+        save_tube_entry(args, m, info, error=ydl_errors)
